@@ -237,6 +237,17 @@ class IMAPSequenceSetTest < Test::Unit::TestCase
   test ".[frozen SequenceSet] returns that SequenceSet" do
     frozen_seqset = SequenceSet[123..456]
     assert_same frozen_seqset, SequenceSet[frozen_seqset]
+
+    coercible = Object.new
+    frozen_seqset = SequenceSet[192, 168, 1, 255]
+    coercible.define_singleton_method(:to_sequence_set) { frozen_seqset }
+    assert_same frozen_seqset, SequenceSet[coercible]
+
+    coercible = Object.new
+    mutable_seqset = SequenceSet.new([192, 168, 1, 255])
+    coercible.define_singleton_method(:to_sequence_set) { mutable_seqset }
+    assert_equal mutable_seqset, SequenceSet[coercible]
+    refute_same  mutable_seqset, SequenceSet[coercible]
   end
 
   test ".new, input may be empty" do
@@ -273,6 +284,36 @@ class IMAPSequenceSetTest < Test::Unit::TestCase
     assert_raise DataFormatError do SequenceSet.try_convert(obj) end
   end
 
+  test "Net::IMAP::SequenceSet(set)" do
+    assert_equal SequenceSet.empty,   Net::IMAP::SequenceSet()
+    assert_equal SequenceSet.empty,   Net::IMAP::SequenceSet(nil)
+    assert_equal SequenceSet.empty,   Net::IMAP::SequenceSet([])
+    assert_equal SequenceSet.empty,   Net::IMAP::SequenceSet([[]])
+    assert_equal SequenceSet.empty,   Net::IMAP::SequenceSet("")
+    assert_equal SequenceSet[123],    Net::IMAP::SequenceSet(123)
+    assert_equal SequenceSet[12..34], Net::IMAP::SequenceSet(12..34)
+    assert_equal SequenceSet[12..34], Net::IMAP::SequenceSet("12:34")
+
+    refute Net::IMAP::SequenceSet("").frozen?
+
+    assert_raise DataFormatError do Net::IMAP::SequenceSet(Object.new) end
+
+    set = SequenceSet[123]
+    assert_same set, Net::IMAP::SequenceSet(set)
+
+    set = SequenceSet.new(123)
+    assert_same set, Net::IMAP::SequenceSet(set)
+
+    obj = Object.new
+    set = SequenceSet[192, 168, 1, 255]
+    obj.define_singleton_method(:to_sequence_set) { set }
+    assert_same set, Net::IMAP::SequenceSet(obj)
+
+    obj = Object.new
+    def obj.to_sequence_set; 192_168.001_255 end
+    assert_raise DataFormatError do Net::IMAP::SequenceSet(obj) end
+  end
+
   test "#at(non-negative index)" do
     assert_nil        SequenceSet.empty.at(0)
     assert_equal   1, SequenceSet[1..].at(0)
@@ -794,13 +835,16 @@ class IMAPSequenceSetTest < Test::Unit::TestCase
   end
 
   test "#include?" do
-    assert SequenceSet["2:4"].include?(3)
-    assert SequenceSet["2,*:12"].include? :*
-    assert SequenceSet["2,*:12"].include?(-1)
+    assert_equal true, SequenceSet["2:4"].include?(3)
+    assert_equal true, SequenceSet["2,*:12"].include?(:*)
+    assert_equal true, SequenceSet["2,*:12"].include?(-1)
+    assert_nil SequenceSet["1:*"].include?("hopes and dreams")
+    assert_nil SequenceSet["1:*"].include?(:wat?)
+    assert_nil SequenceSet["1:*"].include?([1, 2, 3])
     set = SequenceSet.new Array.new(100) { rand(1..1500) }
     rev = (~set).limit(max: 1_501)
-    set.numbers.each do assert set.include?(_1) end
-    rev.numbers.each do refute set.include?(_1) end
+    set.numbers.each do assert_equal true,  set.include?(_1) end
+    rev.numbers.each do assert_equal false, set.include?(_1) end
   end
 
   test "#cover?" do
